==> zio-aws-lexmodelsv2_2.12-5.17.205.1-sources.jar: zio/aws/lexmodelsv2/model/BotStatus.scala <==
package zio.aws.lexmodelsv2.model
import scala.jdk.CollectionConverters._
sealed trait BotStatus {
  def unwrap: software.amazon.awssdk.services.lexmodelsv2.model.BotStatus
}
object BotStatus {
  def wrap(
      value: software.amazon.awssdk.services.lexmodelsv2.model.BotStatus
  ): zio.aws.lexmodelsv2.model.BotStatus = value match {
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.CREATING =>
      val r = Creating
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.AVAILABLE =>
      val r = Available
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.INACTIVE =>
      val r = Inactive
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.DELETING =>
      val r = Deleting
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.FAILED =>
      val r = Failed
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.VERSIONING =>
      val r = Versioning
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.IMPORTING =>
      val r = Importing
      r
  }
  case object unknownToSdkVersion extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object Creating extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.CREATING
  }
  case object Available extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.AVAILABLE
  }
  case object Inactive extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.INACTIVE
  }
  case object Deleting extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.DELETING
  }
  case object Failed extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.FAILED
  }
  case object Versioning extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.VERSIONING
  }
  case object Importing extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.IMPORTING
  }
}

==> zio-aws-lexmodelsv2_2.12-7.21.15.13-sources.jar: zio/aws/lexmodelsv2/model/BotStatus.scala <==
package zio.aws.lexmodelsv2.model
import scala.jdk.CollectionConverters._
sealed trait BotStatus {
  def unwrap: software.amazon.awssdk.services.lexmodelsv2.model.BotStatus
}
object BotStatus {
  def wrap(
      value: software.amazon.awssdk.services.lexmodelsv2.model.BotStatus
  ): zio.aws.lexmodelsv2.model.BotStatus = value match {
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.UNKNOWN_TO_SDK_VERSION =>
      val r = unknownToSdkVersion
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.CREATING =>
      val r = Creating
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.AVAILABLE =>
      val r = Available
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.INACTIVE =>
      val r = Inactive
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.DELETING =>
      val r = Deleting
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.FAILED =>
      val r = Failed
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.VERSIONING =>
      val r = Versioning
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.IMPORTING =>
      val r = Importing
      r
    case software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.UPDATING =>
      val r = Updating
      r
  }
  case object unknownToSdkVersion extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.UNKNOWN_TO_SDK_VERSION
  }
  case object Creating extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.CREATING
  }
  case object Available extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.AVAILABLE
  }
  case object Inactive extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.INACTIVE
  }
  case object Deleting extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.DELETING
  }
  case object Failed extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.FAILED
  }
  case object Versioning extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.VERSIONING
  }
  case object Importing extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.IMPORTING
  }
  case object Updating extends zio.aws.lexmodelsv2.model.BotStatus {
    override def unwrap
        : software.amazon.awssdk.services.lexmodelsv2.model.BotStatus =
      software.amazon.awssdk.services.lexmodelsv2.model.BotStatus.UPDATING
  }
}
